Learn R Programming

RODBCDBI (version 0.1.1)

ODBC: Generate an object of ODBCDriver class

Description

This driver is for implementing the R database (DBI) API. This class should always be initialized with the ODBC() function. ODBC driver does nothing for ODBC connection. It just exists for S4 class compatibility with DBI package.

Usage

ODBC()

Arguments

Examples

Run this code
## Not run: 
# driver <- RODBCDBI::ODBC()
# # Connect to a ODBC data source
# con <- dbConnect(driver, dsn="test")
# # Always cleanup by disconnecting the database
# #' dbDisconnect(con)
# ## End(Not run)

Run the code above in your browser using DataLab